@@ -486,7 +486,7 @@ class Work:
 
             if constraint_finish:
                 late_finish = self.add_hours(work.company, constraint_finish,
-                        -work.back_leveling_delay)
+                        -(work.back_leveling_delay or 0.0))
             else:
                 late_finish = None
 
@@ -598,9 +598,8 @@ class Work:
 
                 yield sibling, delay
 
-        parent = self.parent and self.parent.id or None
         siblings = self.search([
-                ('parent', '=', parent.id)
+                ('parent', '=', self.parent.id if self.parent else None)
                 ])
 
         refkey = get_key(self)
@@ -617,8 +616,8 @@ class Work:
                     'back_leveling_delay': delay,
                     })
 
-        if parent:
-            parent.compute_dates()
+        if self.parent:
+            self.parent.compute_dates()
 
     @classmethod
     def write(cls, works, values):
